@@ -17,15 +17,13 @@ class TestFrame(wx.Frame):
 
         kwds["style"] = wx.DEFAULT_FRAME_STYLE|wx.RESIZE_BORDER|wx.TAB_TRAVERSAL
 
-        wx.Frame.__init__(self, parent, wx.NewId(), '',
+        wx.Frame.__init__(self, parent, -1, '',
                          wx.DefaultPosition, wx.Size(-1,-1), **kwds)
         self.SetTitle(" WXMPlot Plotting Demo")
 
         self.SetFont(wx.Font(12,wx.SWISS,wx.NORMAL,wx.BOLD,False))
         menu = wx.Menu()
-        ID_EXIT  = wx.NewId()
-
-        menu_exit = menu.Append(ID_EXIT, "E&xit", "Terminate the program")
+        menu_exit = menu.Append(-1, "E&xit", "Terminate the program")
 
         menuBar = wx.MenuBar()
         menuBar.Append(menu, "&File");
@@ -44,7 +42,7 @@ class TestFrame(wx.Frame):
         panelsizer = wx.BoxSizer(wx.VERTICAL)
 
         panelsizer.Add( wx.StaticText(panel, -1, 'wxmplot 2D PlotPanel examples '),
-                        0, wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.LEFT|wx.EXPAND, 10)
+                        0, wx.ALIGN_LEFT|wx.LEFT|wx.EXPAND, 10)
 
         b10 = wx.Button(panel, -1, 'Example #1',          size=(-1,-1))
         b20 = wx.Button(panel, -1, 'Example #2',          size=(-1,-1))
@@ -87,7 +85,7 @@ class TestFrame(wx.Frame):
         panel.SetSizer(panelsizer)
         panelsizer.Fit(panel)
 
-        framesizer.Add(panel, 0, wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.EXPAND,2)
+        framesizer.Add(panel, 0, wx.ALIGN_LEFT|wx.EXPAND,2)
         self.SetSizer(framesizer)
         framesizer.Fit(self)
 
@@ -287,9 +285,9 @@ class TestFrame(wx.Frame):
 
     def OnAbout(self, event):
         dlg = wx.MessageDialog(self, "This sample program shows some\n"
-                              "examples of MPlot PlotFrame.\n"
+                              "examples of WXMPlot PlotFrame.\n"
                               "message dialog.",
-                              "About MPlot test", wx.OK | wx.ICON_INFORMATION)
+                              "About WXMPlot test", wx.OK | wx.ICON_INFORMATION)
         dlg.ShowModal()
         dlg.Destroy()
 
