@@ -29,11 +29,7 @@ class StripChartFrame(wx.Frame):
 
         self.SetFont(wx.Font(12,wx.SWISS,wx.NORMAL,wx.BOLD,False))
         menu = wx.Menu()
-        ID_EXIT  = wx.NewId()
-        ID_TIMER = wx.NewId()
-
-        menu_exit = menu.Append(ID_EXIT, "E&xit",
-                                "Terminate the program")
+        menu_exit = menu.Append(-1, "E&xit", "Terminate the program")
 
         menuBar = wx.MenuBar()
         menuBar.Append(menu, "&File");
@@ -67,7 +63,7 @@ class StripChartFrame(wx.Frame):
 
         btnsizer.Add(b_on,   0, wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.LEFT, 0)
         btnsizer.Add(b_off,  0, wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.LEFT, 0)
-        btnsizer.Add(tlabel, 1, wx.GROW|wx.ALL|wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.LEFT, 0)
+        btnsizer.Add(tlabel, 1, wx.GROW|wx.ALL|wx.ALIGN_LEFT|wx.LEFT, 0)
         btnsizer.Add(self.time_range, 0, wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.LEFT, 0)
 
         btnpanel.SetSizer(btnsizer)
@@ -76,16 +72,14 @@ class StripChartFrame(wx.Frame):
         self.plotpanel = PlotPanel(self, messenger=self.write_message)
         self.plotpanel.BuildPanel()
         self.plotpanel.set_xlabel('Time from Present (s)')
-        mainsizer.Add(btnpanel,       0,
-                      wx.GROW|wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.LEFT, 0)
-        mainsizer.Add(self.plotpanel, 1,
-                      wx.GROW|wx.ALL|wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.LEFT, 0)
+        mainsizer.Add(btnpanel, 0,  wx.GROW|wx.ALIGN_LEFT|wx.LEFT, 0)
+        mainsizer.Add(self.plotpanel, 1, wx.GROW|wx.ALL|wx.ALIGN_LEFT|wx.LEFT, 0)
         self.SetSizer(mainsizer)
         mainsizer.Fit(self)
 
         self.Bind(wx.EVT_TIMER, self.onTimer)
         self.timer = wx.Timer(self)
-        self.count    = 0
+        self.count = 0
         self.Refresh()
         wx.CallAfter(self.onStartTimer)
 
@@ -100,7 +94,7 @@ class StripChartFrame(wx.Frame):
         self.tlist = [t0]
         self.tmin_last = -10000
         self.time0    = time.time()
-        self.timer.Start(50)
+        self.timer.Start(25)
 
     def onStopTimer(self,event=None):
         self.timer.Stop()
@@ -121,19 +115,19 @@ class StripChartFrame(wx.Frame):
             self.plotpanel.plot(tdat, ydat)
         else:
             self.plotpanel.update_line(0, tdat, ydat, draw=True)
-            self.write_message(" %i points in %8.4f s" % (n,etime))
+            self.write_message("update  %i points in %8.4f s" % (n,etime))
 
         lims = self.plotpanel.get_viewlimits()
         try:
             ymin, ymax = ydat[mask].min(), ydat[mask].max()
         except:
             ymin, ymax = ydat.min(), ydat.max()
-        tmin = max(int(min(tdat)) - 1.0, -self.tmin)
-        if (ymin < lims[2] or ymax >  lims[3] or
-            tmin != self.tmin_last or time.time()-self.last_update > 2):
-            self.tmin_last = tmin
-            self.last_update = time.time()
-            self.plotpanel.set_xylims((tmin, 0, ymin, ymax))
+        yrange = abs(ymax-ymin)
+        ymin -= yrange*0.05
+        ymax += yrange*0.05
+
+        if (ymin < lims[2] or ymax >  lims[3] ):
+            self.plotpanel.set_xylims((-self.tmin, 0, ymin, ymax))
 
     def OnAbout(self, event):
         dlg = wx.MessageDialog(self, "wxmplot example: stripchart app",
